@@ -27,6 +27,7 @@
 #include <fstream>
 
 #include <cif++.hpp>
+// #include <gxrio.hpp>
 #include <mcfp/mcfp.hpp>
 
 #include "revision.hpp"
@@ -71,14 +72,20 @@ int pr_main(int argc, char *argv[])
 		mcfp::make_option("help,h", "Display help message"),
 		mcfp::make_option("version", "Print version"),
 		mcfp::make_option<std::string>("dict", "mmcif_pdbx.dic", "The mmCIF dictionary to use, can be either mmcif_ddl, mmcif_pdbx or a path to the actual dictionary file"),
-		mcfp::make_option("validate-pdbx", "Validate PDBx categories, assuming mmcif_pdbx, and checks entity, entity_poly, entity_poly_seq and pdbx_poly_seq_scheme for consistency with atom_site"),
-		mcfp::make_option("validate-links", "Validate all links"),
-		mcfp::make_option("validate-data-comp", "Default is to skip data_comp_XXX datablocks, use this flag to force validation"),
+		mcfp::make_option("validate-all-datablocks,F", "Default is to validate only the first datablock, use this flag to force validation of all datablocks"),
 		mcfp::make_option("syntax-only", "Quickly check to see if the syntax is correct"),
 		mcfp::make_option("verbose,v", "Verbose output, repeat to increase verbosity level"),
-		mcfp::make_option("print", "Print the reformatted file, to stdout or, when specified, to 'output-file'"));
+		mcfp::make_option("print", "Print the reformatted file, to stdout or, when specified, to 'output-file'"),
+		mcfp::make_option("strip", "Strip invalid categories and items"));
 
-	config.parse(argc, argv);
+	std::error_code ec;
+	config.parse(argc, argv, ec);
+
+	if (ec)
+	{
+		std::cerr << "Error parsing command line option " << std::quoted(config.get_last_option()) << ": " << ec.message() << '\n';
+		exit(1);
+	}
 
 	if (config.has("version"))
 	{
@@ -88,7 +95,7 @@ int pr_main(int argc, char *argv[])
 
 	if (config.has("help") or config.operands().empty())
 	{
-		std::cerr << config << std::endl;
+		std::cerr << config << '\n';
 		exit(config.has("help") ? 0 : 1);
 	}
 
@@ -102,46 +109,71 @@ int pr_main(int argc, char *argv[])
 	{
 		cif::file f(config.operands().front());
 
-		if (not config.has("syntax-only"))
+		for (auto &db : f)
 		{
 			if (config.count("dict"))
-				f.load_dictionary(config.get<std::string>("dict"));
-			else if (config.has("validate-pdbx"))
-				f.load_dictionary("mmcif_pdbx");
-
-			if (f.get_validator() == nullptr)
-			{
-				std::cerr << "No validator, please specify a dictionary to use using the --dict option" << std::endl
-						  << "However, the syntax seems to be OK" << std::endl;
-			}
+				db.set_validator(&cif::validator_factory::instance().get(config.get<std::string>("dict")));
 			else
+				db.load_dictionary();
+			
+			if (db.get_validator() == nullptr)
+				db.set_validator(&cif::validator_factory::instance().get("mmcif_pdbx.dic"));
+
+			if (not const_cast<const cif::datablock &>(db).is_valid())
+				result = 1;
+			
+			if (not config.has("validate-all-datablocks"))
+				break;
+		}
+
+		if (config.has("validate-pdbx"))
+		{
+			if (not cif::pdb::is_valid_pdbx_file(f, ec))
 			{
-				for (auto &db : f)
-				{
-					if (cif::starts_with(db.name(), "comp_") and not config.has("validate-data-comp"))
-						continue;
-
-					if (not db.is_valid())
-						result = 1;;
-				}
-
-				if (config.has("validate-links"))
-					f.validate_links();
-				
-				if (config.has("validate-pdbx"))
-					result = result and cif::pdb::is_valid_pdbx_file(f);
+				std::cerr << "Not a valid pdbx file: " << ec.message() << "\n";
+				result = 1;
 			}
 		}
 
-		if (config.has("print"))
+		if (config.has("strip"))
+		{
+			result = 0;
+
+			for (auto &db : f)
+			{
+				if (db.get_validator() == nullptr)
+				{
+					if (cif::VERBOSE > 0)
+						std::cerr << "Cannot strip datablock " << db.name() << " since it has no dictionary\n";
+					continue;
+				}
+
+				if (not db.strip())
+				{
+					std::clog << "Stripping datablock " << db.name() << " did not result in a valid file\n";
+					result = 1;
+				}
+				
+				if (not config.has("validate-all-datablocks"))
+					break;
+			}
+		}
+
+		if (config.has("validate-links"))
+		{
+			if (not f.validate_links())
+				result = 1;
+		}
+		
+		if (result == 0 and (config.has("print") or config.has("strip")))
 		{
 			if (config.operands().size() == 1)
 				f.save(std::cout);
 			else
 			{
-				std::ofstream out(config.operands()[1]);
+				cif::gzio::ofstream out(config.operands()[1]);
 				if (not out.is_open())
-					std::cerr << "Could not open output file" << std::endl;
+					std::cerr << "Could not open output file\n";
 				else
 					f.save(out);
 			}
